@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: build_boilerplate.py 9935 2017-05-01 13:54:31Z Lavender $
+# $Id: build_boilerplate.py 9978 2017-05-20 15:24:37Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-05-01 21:54:31 +0800 (週一, 01 五月 2017) $
-# $Revision: 9935 $
+# $Date: 2017-05-20 23:24:37 +0800 (週六, 20 五月 2017) $
+# $Revision: 9978 $
 
 import os
 import sys
@@ -24,9 +24,11 @@ import hashlib
 from lxml import etree
 from lxml.html.soupparser import parse
 from django.core.management.base import BaseCommand, CommandError
-from django.conf import settings
 from django.template.loader import get_template
 
+from Zephyrus.boilerplate.management.commands import (
+    TEMPLATES_DIR_PATH, STATIC_DIR_PATH)
+
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
 handler = logging.StreamHandler()
@@ -61,26 +63,6 @@ CMS_HEAD_BACK_TAG = "{% render_block 'css' %}"
 CMS_BODY_FRONT_TAG = "{% cms_toolbar %}"
 CMS_BODY_BACK_TAG = "{% render_block 'js' %}"
 
-# settings
-if settings.DEBUG:
-    if hasattr(settings, 'STATICFILES_DIRS'):
-        STATIC_DIT_PATH = settings.STATICFILES_DIRS[0]
-    else:
-        STATIC_DIT_PATH = os.path.abspath(
-            os.path.join('.', 'static'))
-else:
-    if hasattr(settings, 'STATIC_ROOT'):
-        STATIC_DIT_PATH = settings.STATIC_ROOT
-    else:
-        STATIC_DIT_PATH = os.path.abspath(
-            os.path.join('.', 'static'))
-            
-if hasattr(settings, 'TEMPLATES'):
-    TEMPLATES_DIR_PATH = settings.TEMPLATES[0]['DIRS'][0]
-else:
-    TEMPLATES_DIR_PATH = os.path.abspath(
-        os.path.join('.', 'templates'))
-
 class Command(BaseCommand):
 
     help = 'Add placeholder to templates'
@@ -174,9 +156,9 @@ class Command(BaseCommand):
         fileDict = {}
         
         if path == 'static':
-            for root, dirs, files in os.walk(STATIC_DIT_PATH):
+            for root, dirs, files in os.walk(STATIC_DIR_PATH):
                 for f in files:
-                    index = len(STATIC_DIT_PATH) + 1
+                    index = len(STATIC_DIR_PATH) + 1
                     filePath = os.path.join(root, f)[index:].replace('\\', '/')
                     fileDict[filePath] = hashlib.md5(filePath).hexdigest()
         elif path == 'templates':
