@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 9895 2017-04-23 04:33:47Z Lavender $
+# $Id: __init__.py 9919 2017-04-27 07:05:09Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,22 +12,11 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-04-23 12:33:47 +0800 (週日, 23 四月 2017) $
-# $Revision: 9895 $
+# $Date: 2017-04-27 15:05:09 +0800 (週四, 27 四月 2017) $
+# $Revision: 9919 $
 
 class ErrorCode(object):
     NORMAL = 0
     SAVE_EMAIL = 1
     SEND_EMAIL = 2
-    EMAIL_FORMAT = 3
-
-
-def getErrorMessage(code):
-    if code == ErrorCode.SAVE_EMAIL:
-        return "Save Email Error"
-    elif code == ErrorCode.SEND_EMAIL:
-        return "Send Email Error"
-    elif code == ErrorCode.EMAIL_FORMAT:
-        return "Email Format Error"
-    else:
-        return None
\ No newline at end of file
+    EMAIL_FORMAT = 3
\ No newline at end of file
